/***************************************************************************
                          rbuttongroup.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

/****************************************************************************
** rbuttongroup.h 1998/09/19 A. Mustun RibbonSoft
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#ifndef RBUTTONGROUP_H
#define RBUTTONGROUP_H

#include <qbuttongroup.h>

/*! Implementation of QButtonGroup
    (Uses a better font)
*/
class RButtonGroup : public QButtonGroup
{
  Q_OBJECT
public:
  /*! Constructor 1
      \param _parent The parent widget
      \param _name Name
  */
  RButtonGroup(QWidget* _parent=0, const char* _name=0);
  /*! Constructor 2
      \param _title The title of the button group
      \param _parent The parent widget
      \param _name Name
  */
  RButtonGroup(const QString& _title, QWidget* _parent=0, const char* _name=0);
  /*! Destructor
  */
  ~RButtonGroup();

};


#endif

// EOF

